@@ -6,7 +6,7 @@ use warnings;
 use Perl::Critic::Utils qw(:severities :classification :ppi);
 use parent 'Perl::Critic::Policy';
 
-our $VERSION = '0.001';
+our $VERSION = '0.002';
 
 use constant DESC => 'Using interpreter threads';
 use constant EXPL => 'Interpreter threads are discouraged, they are not lightweight and fast as other threads may be. Try an event loop, forks.pm, or Parallel::Prefork.';
@@ -26,7 +26,8 @@ sub violates {
 
 =head1 NAME
 
-Perl::Critic::Policy::Freenode::Threads
+Perl::Critic::Policy::Freenode::Threads - Interpreter-based threads are
+officially discouraged
 
 =head1 DESCRIPTION
 
