@@ -6,7 +6,7 @@ use warnings;
 use Perl::Critic::Utils qw(:severities :classification :ppi);
 use parent 'Perl::Critic::Policy';
 
-our $VERSION = '0.001';
+our $VERSION = '0.002';
 
 use constant DESC => '<> operator result not explicitly assigned in while condition';
 use constant EXPL => 'When used alone in a while condition, the <> operator assigns its result to $_, but does not localize it. Assign the result to an explicit lexical variable instead (my $line = <...>)';
@@ -54,7 +54,8 @@ sub violates {
 
 =head1 NAME
 
-Perl::Critic::Policy::Freenode::WhileDiamondDefaultAssignment
+Perl::Critic::Policy::Freenode::WhileDiamondDefaultAssignment - Don't use while
+with implicit assignment to $_
 
 =head1 DESCRIPTION
 
